@@ -7,7 +7,7 @@ function(x,para) {
     U  <- para$para[2]
     A  <- para$para[3]
 
-    f <- vector(mode="numeric")
+    f <- vector(mode="numeric", length=length(x))
     for(i in seq(1,length(x))) {
       if(x[i] <= 0) {
          f[i] <- NA
