@@ -4,12 +4,12 @@ function(x, leftpara, rightpara, weight=NULL, ...) {
     end.max <- 1-.Machine$double.eps
     qua.min <- par2qua2(end.min,leftpara,rightpara,...)
     qua.max <- par2qua2(end.max,leftpara,rightpara,...)
-    f <- vector(mode="numeric")
+    f <- vector(mode="numeric", length=length(x))
     for(i in seq(1,length(x))) {
       QUAx <- x[i]
       if(QUAx <= qua.min) { f[i] <- end.min; next }
       if(QUAx >= qua.max) { f[i] <- end.max; next }
-      
+
       "fn" <- function(F) {
         qua <- par2qua2(F, leftpara, rightpara, weight, ...)
         val <- QUAx - qua
