@@ -2,7 +2,7 @@
 function(lmom,checklmom=TRUE) {
     para <- vector(mode="numeric", length=3)
     names(para) <- c("xi","alpha","kappa")
-    erf <- function(x) 2 * pnorm(x * sqrt(2)) - 1
+    "erf" <- function(x) 2 * pnorm(x * sqrt(2)) - 1
 
     # METHOD: RATIONAL-FUNCTION APPROXIMATION OF K IN TERMS OF TAU-3
     #  COEFFICIENTS OF RATIONAL-FUNCTION APPROXIMATION
