@@ -1,5 +1,5 @@
 "pargov" <-
-function(lmom,checklmom=TRUE) {
+function(lmom, xi=NULL, checklmom=TRUE) {
     para <- vector(mode="numeric", length=3)
     names(para) <- c("xi","alpha", "beta")
     if(length(lmom$L1) == 1) { # convert to named L-moments
@@ -12,24 +12,22 @@ function(lmom,checklmom=TRUE) {
     L1 <- lmom$lambdas[1]
     L2 <- lmom$lambdas[2]
     T3 <- lmom$ratios[3]
+    B <- -1*(4*T3 + 2)/(T3 - 1)
 
-    "t3f" <- function(b, t3) return(t3 - ((b - 2)/(b + 4)))
-    tmp <- NULL
-    try(tmp <- uniroot(t3f, lower=0, upper=100000, t3=T3), silent=TRUE)
-    if(is.null(tmp)) {
-      B <- NA
+    if(is.null(xi)) {   
+       A <- (B+2)*(B+3)*L2/(2*B)
+       U <- L1 - 2*A/(B+2)
     } else {
-      B <- tmp$root
+       U <- xi
+       A <- (L1 - U) * (B + 2) / 2
     }
-    A <- (B+2)*(B+3)*L2/(2*B)
-    U <- L1 - 2*A/(B+2)
     para[1] <- U
     para[2] <- A
     para[3] <- B
     z <- list(para=para, type="gov", source="pargov")
 
     if(! are.pargov.valid(z)) {
-        warning("After estimate, either A or B is <= 0")
+        warning("After estimation, either A or B is <= 0")
     }
     return(z)
 }
