@@ -17,7 +17,7 @@ function(x,para) {
 
     Fs <- cdfkap(x,para)
  
-    f <- vector(mode = "numeric")
+    f <- vector(mode = "numeric", length=length(x))
     for(i in seq(1,length(x))) {
       Y  <- (x[i] - XI)/A
       if(K != 0) {
