@@ -9,9 +9,8 @@ function(f,gldpara,paracheck=TRUE) {
     La2 <- gldpara$para[2]
     La3 <- gldpara$para[3]
     La4 <- gldpara$para[4]
-    n <- length(f)
-    x <- vector(mode="numeric",length=n)
-    for(i in seq(1,n)) {
+    x <- vector(mode="numeric", length=length(f))
+    for(i in seq(1,length(f))) {
       if(f[i] == 0) { x[i] <- La1-La2; next }
       if(f[i] == 1) { x[i] <- La1+La2; next }
       x[i] <- La1 + La2*(f[i]**La3 - (1-f[i])**La4)
