@@ -7,9 +7,8 @@ function(f,para,paracheck=TRUE) {
     XI <- para$para[1]
     A  <- para$para[2]
     K  <- para$para[3]
-    n <- length(f)
-    x <- vector(mode="numeric",length=n)
-    for(i in seq(1,n)) {
+    x <- vector(mode="numeric", length=length(f))
+    for(i in seq(1,length(f))) {
       if(f[i] == 0)         { x[i] <- XI; next }
       if(f[i] == 1 & K > 0) { x[i] <- XI+A/K; next }
       Y <- -log(1 - f[i])
