@@ -1,16 +1,15 @@
 "quakap" <-
 function(f,para,paracheck=TRUE) {
     if(! check.fs(f)) return()
-    if(paracheck == TRUE) { 
+    if(paracheck == TRUE) {
       if(! are.parkap.valid(para)) return()
     }
     U <- para$para[1]
     A <- para$para[2]
     G <- para$para[3]
     H <- para$para[4]
-    n <- length(f)
-    x <- vector(mode="numeric",length(f))
-    for(i in seq(1,n)) {
+    x <- vector(mode="numeric", length=length(f))
+    for(i in seq(1,length(f))) {
       if(f[i] == 0) {
         if(H <= 0 & G  < 0) { x[i] <- U+A/G; next }
         if(H >  0 & G != 0) { x[i] <- U+A/G*(1-H^-G); next }
